@@ -1,9 +1,8 @@
 import libra_client
 from libra.crypto.ed25519 import ED25519_PRIVATE_KEY_LENGTH, ED25519_SIGNATURE_LENGTH
 from libra.transaction import *
-from libra_client.error import AccountError, TransactionError, TransactionTimeoutError
+from libra_client.error import LibraError, AccountError, TransactionError, TransactionTimeoutError
 from canoser import Uint64
-from libra.proto.get_with_proof_pb2 import UpdateToLatestLedgerRequest
 import pytest
 import nacl
 import os
@@ -15,20 +14,20 @@ def test_raw_txn():
     a0 = wallet.accounts[0]
     a1 = wallet.accounts[1]
     raw_tx = RawTransaction._gen_transfer_transaction(a0.address, 0, a1.address, 123)
-    assert raw_tx.max_gas_amount == 400_000
+    assert raw_tx.max_gas_amount == MAX_GAS_AMOUNT
     assert raw_tx.gas_unit_price == 0
     assert bytes(raw_tx.sender) == a0.address
     assert raw_tx.payload.enum_name == "Script"
-    assert raw_tx.payload.index == 2
+    assert raw_tx.payload.index == 1
     assert raw_tx.payload.value_type == Script
     script = raw_tx.payload.value
-    assert script.code == Script.get_script_bytecode("peer_to_peer")
+    assert script.code == Script.get_script_bytecode("peer_to_peer_with_metadata")
     assert script.args[0].index == 3
     assert script.args[0].Address == True
     assert script.args[0].enum_name == 'Address'
-    assert script.args[2].index == 1
-    assert script.args[2].U64 == True
-    assert script.args[2].value == 123
+    assert script.args[1].index == 1
+    assert script.args[1].U64 == True
+    assert script.args[1].value == 123
 
 
 def test_raw_txn_with_metadata():
@@ -42,12 +41,12 @@ def test_raw_txn_with_metadata():
     assert script.args[0].index == 3
     assert script.args[0].Address == True
     assert script.args[0].enum_name == 'Address'
-    assert script.args[2].index == 1
-    assert script.args[2].U64 == True
-    assert script.args[2].value == 9
-    assert script.args[3].index == 4
-    assert script.args[3].U8Vector == True
-    assert script.args[3].value == bytes([2,3,4])
+    assert script.args[1].index == 1
+    assert script.args[1].U64 == True
+    assert script.args[1].value == 9
+    assert script.args[2].index == 4
+    assert script.args[2].U8Vector == True
+    assert script.args[2].value == bytes([2,3,4])
 
 
 def test_signed_txn():
@@ -62,20 +61,6 @@ def test_signed_txn():
         stx.authenticator = authenticator
         stx.check_signature()
 
-def test_wait_for_transaction_timeout():
-    wallet = libra_client.WalletLibrary.recover('test/test.wallet')
-    a0 = wallet.accounts[0]
-    a1 = wallet.accounts[1]
-    c = libra_client.Client("testnet")
-    diff = c._get_time_diff()
-    if diff < 0:
-        with pytest.raises(libra_client.VMError) as excinfo:
-            c.transfer_coin(a0, a1.address, 1, unit_price=0, is_blocking=True, txn_expiration=0)
-        vm_error = excinfo.value
-        assert vm_error.args == (6, 'TRANSACTION_EXPIRED')
-        assert vm_error.error_code == 6
-        assert vm_error.error_msg == 'TRANSACTION_EXPIRED'
-
 
 def test_gax_too_large():
     wallet = libra_client.WalletLibrary.recover('test/test.wallet')
@@ -86,12 +71,12 @@ def test_gax_too_large():
         balance0 = c.get_balance(a0.address)
     except AccountError:
         balance0 = 0
-    with pytest.raises((AccountError, TransactionError)):
-        c.transfer_coin(a0, a1.address, 1, unit_price=balance0)
-    with pytest.raises((AccountError, TransactionError)):
-        c.transfer_coin(a0, a1.address, 1, max_gas=1_000_000_001)
-    with pytest.raises((AccountError, TransactionError)):
-        c.transfer_coin(a0, a1.address, 1, max_gas=balance0+1, unit_price=10000)
+    with pytest.raises(LibraError):
+        c.transfer_coin(a0, a1.address, 1, gas_unit_price=balance0)
+    with pytest.raises(LibraError):
+        c.transfer_coin(a0, a1.address, 1, max_gas_amount=1_000_000_001)
+    with pytest.raises(LibraError):
+        c.transfer_coin(a0, a1.address, 1, max_gas_amount=balance0+1, gas_unit_price=10000)
 
 
 def test_amount_zero():
@@ -101,9 +86,7 @@ def test_amount_zero():
     c = libra_client.Client("testnet")
     try:
         ret = c.transfer_coin(a0, a1.address, 0, is_blocking=True)
-    except libra_client.client.VMError as vme:
-        assert vme.error_code == 4016 or vme.error_code == 7
-    except libra_client.client.MempoolError as mpe:
+    except LibraError as ae:
         pass
 
 
@@ -144,43 +127,31 @@ def test_amount_illegal():
     try:
         c.transfer_coin(a0, a1.address, balance0+99999999, is_blocking=False)
         c.wait_for_transaction(a0.address, sequence_number) #no events emitted
-    except libra_client.client.VMError as vme:
-        assert vme.error_code == 4016 or vme.error_code == 7
-    except libra_client.client.MempoolError as mpe:
+    except LibraError as mpe:
         pass
 
+
 def test_query():
     c = libra_client.Client("testnet")
-    txs = c.get_transactions(1, "1")
-    txs = c.get_transactions("1", 1)
-    txs = c.get_transactions(1, "1", False)
-    with pytest.raises(TypeError):
+    with pytest.raises(LibraError):
+        txs = c.get_transactions(1, "1")
+    with pytest.raises(LibraError):
+        txs = c.get_transactions("1", 1)
+    with pytest.raises(LibraError):
+        txs = c.get_transactions(1, "1", False)
+    with pytest.raises(LibraError):
         c.get_transactions(1, True)
 
 
 def test_get_transaction_invalid():
     client = libra_client.Client("testnet")
-    with pytest.raises(TypeError):
+    with pytest.raises(LibraError):
         client.get_transaction(-1)
     tx = client.get_transaction(Uint64.max_value)
     assert tx is None
-    with pytest.raises(TypeError):
+    with pytest.raises(LibraError):
         client.get_transaction(Uint64.max_value+1)
 
-def test_tx_id_overflow():
-    client = libra_client.Client("testnet")
-    start_version = Uint64.max_value+1
-    request = UpdateToLatestLedgerRequest()
-    item = request.requested_items.add()
-    with pytest.raises(ValueError):
-        item.get_transactions_request.start_version = start_version
-    with pytest.raises(ValueError):
-        item.get_transactions_request.start_version = -1
-    # item.get_transactions_request.limit = 1
-    # item.get_transactions_request.fetch_events = False
-    # resp = client.update_to_latest_ledger(request)
-    # print(resp)
-
 
 def test_transfer_with_metadata():
     wallet = libra_client.WalletLibrary.recover('test/test.wallet')
@@ -194,7 +165,7 @@ def test_transfer_with_metadata():
     try:
         client.create_account(a0, a1.address, a1.auth_key_prefix, is_blocking=True)
     except libra_client.error.VMError as err:
-        if err.error_code == 4012:
+        if err.error_code == 4016:
             pass
         else:
             raise
@@ -208,13 +179,9 @@ def test_transfer_with_metadata():
     script = ret.raw_txn.payload.value
     assert script.code == Script.get_script_bytecode("peer_to_peer_with_metadata")
     assert bytes(script.args[0].value) == a1.address
-    assert script.args[2].value == 1
-    assert script.args[3].value == bytes([3,4,5])
-    proto, _ = client.get_account_transaction_proto(ret.raw_txn.sender, ret.raw_txn.sequence_number, True)
-    assert proto.version > 1
-    assert len(proto.events.events) == 2
-    assert proto.proof.transaction_info.major_status == 4001
-    stx = Transaction.deserialize(proto.transaction.transaction).value
-    assert stx.raw_txn == ret.raw_txn
+    assert script.args[1].value == 1
+    assert script.args[2].value == bytes([3,4,5])
+    tx = client.get_account_transaction(ret.raw_txn.sender, ret.raw_txn.sequence_number, True)
+    assert tx.version > 1
 
 
